=======
Roadmap
=======


Summer 2019
===========

* Collaboration phase with researchers

* TensorFlow implementation

* Normalized format
   * Specification freeze
   * Dataset creation utils
   * More tests
   * Collaboration with researchers using new format


Autumn 2019
===========

Conference Talk on Benzina
